@@ -1,9 +1,6 @@
 package Modern::Perl;
-{
-  $Modern::Perl::VERSION = '1.20140107';
-}
 # ABSTRACT: enable all of the features of Modern Perl with one import
-
+$Modern::Perl::VERSION = '1.20150127';
 use 5.010_000;
 
 use strict;
@@ -59,6 +56,7 @@ my %dates =
     2012 => ':5.14',
     2013 => ':5.16',
     2014 => ':5.18',
+    2015 => ':5.20',
 );
 
 sub validate_date
@@ -93,7 +91,7 @@ Modern::Perl - enable all of the features of Modern Perl with one import
 
 =head1 VERSION
 
-version 1.20140107
+version 1.20150127
 
 =head1 SYNOPSIS
 
@@ -144,7 +142,13 @@ optional import tag. For example:
 
     use Modern::Perl '2014';
 
-... enables 5.18 features. Obviously you cannot use newer features on earlier
+... enables 5.18 features, and:
+
+    use Modern::Perl '2015';
+
+... enables 5.20 features.
+
+Obviously you cannot use newer features on earlier
 versions. Perl will throw the appropriate exception if you try.
 
 By mid-2014, this module will drop support for 5.10 and 5.12 and will complain
@@ -215,7 +219,7 @@ chromatic
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by chromatic@wgz.org.
+This software is copyright (c) 2015 by chromatic@wgz.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
